#
# spec file for package arpwatch
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1140
%define has_systemd 1
%endif

Name:           arpwatch
BuildRequires:  libpcap-devel
BuildRequires:  postfix
%if 0%{?has_systemd}
BuildRequires:  systemd
%{?systemd_requires}
%endif
Url:            http://www-nrg.ee.lbl.gov/nrg.html
Requires:       arpwatch-ethercodes
%if 0%{?suse_version} <= 1140
PreReq:         /usr/bin/touch %insserv_prereq %fillup_prereq
%else
PreReq:         /usr/bin/touch %fillup_prereq
%endif
Summary:        Arpwatch Keeps Track of Ethernet and IP Address Pairings
License:        BSD-3-Clause
Group:          Productivity/Networking/Diagnostic
Version:        2.1a15
Release:        160.3
Source:         %{name}-%{version}.tar.bz2
%if 0%{?has_systemd}
Source10:       arpwatch@.service
%else
Source10:       arpwatch.init
%endif
Source11:       sysconfig.arpwatch
Patch0:         arpwatch-2.1a11-chrootbuild.diff
Patch1:         arpwatch-no-source-zero.dif
Patch3:         arpwatch-2.1a11-tokenring.diff
Patch4:         arpwatch-2.1a11-hname-overflow.dif
Patch5:         arpwatch-2.1a11-drop-privs-manpage.dif
Patch6:         arpwatch-2.1a11-drop-privs.dif
Patch7:         arpwatch-2.1a11-emailaddr.dif
Patch8:         arpwatch-2.1a15-massagevendor.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Arpwatch keeps track of Ethernet and IP address pairings. It logs
activity to syslog and reports certain changes via e-mail.

%package ethercodes-build
Summary:        Tool to create ethercodes.dat from IEEE.org meta data
Group:          Productivity/Networking/Diagnostic

%description ethercodes-build
Tool and required files to create the ethercodes.dat file from the OUI
and company ID data as provided by IEEE.org.  This package is only
needed if you want to build the arpwatch-ethercodes package.

%prep
%setup -q
%patch -P 0 -E
%patch1 -p1 -E
%patch3 -p1 -E
%patch4 -p1 -E
%patch5 -p1 -E
%patch6 -p1 -E
%patch7 -p1 -E
%patch8 -p1

%build
%configure 
%{__make} ARPDIR=/var/lib/arpwatch %{?_smp_mflags}

%install
mkdir -p \
%if 0%{?has_systemd}
    $RPM_BUILD_ROOT/%{_unitdir} \
%else
    $RPM_BUILD_ROOT/etc/init.d \
%endif
    $RPM_BUILD_ROOT/%{_sbindir} \
	$RPM_BUILD_ROOT/%{_datadir}/arpwatch \
	$RPM_BUILD_ROOT/%{_mandir}/man8 \
	$RPM_BUILD_ROOT/var/adm/fillup-templates
%makeinstall
# ethercodes.dat is in the arpwatch-ethercodes package
rm -f $RPM_BUILD_ROOT/%{_datadir}/arpwatch/ethercodes.dat
for file in massagevendor euppertolower.awk duplicates.awk p.awk; do
	cp -p ${file} $RPM_BUILD_ROOT/%{_datadir}/arpwatch
done
make DESTDIR=$RPM_BUILD_ROOT install-man
%if 0%{?has_systemd}
install -m 0644 $RPM_SOURCE_DIR/arpwatch@.service $RPM_BUILD_ROOT/%{_unitdir}
%else
install -m 0754 $RPM_SOURCE_DIR/arpwatch.init $RPM_BUILD_ROOT/etc/init.d/arpwatch
ln -sf ../../etc/init.d/arpwatch $RPM_BUILD_ROOT/%{_sbindir}/rcarpwatch
%endif
cp -p ${RPM_SOURCE_DIR}/sysconfig.arpwatch $RPM_BUILD_ROOT/var/adm/fillup-templates
# own the database files
touch $RPM_BUILD_ROOT/var/lib/arpwatch/arp.dat
touch $RPM_BUILD_ROOT/var/lib/arpwatch/arp.dat-

%pre
%if 0%{?has_systemd}
%service_add_pre arpwatch@.service
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun arpwatch@.service
%else
%stop_on_removal arpwatch
%endif

%post
%if 0%{?has_systemd}
%service_add_post arpwatch@.service
%fillup_only
%else
%fillup_and_insserv
%endif
if [ ! -f var/lib/arpwatch/arp.dat ]; then
	touch var/lib/arpwatch/arp.dat
fi

%postun
%if 0%{?has_systemd}
%service_del_postun arpwatch@.service
%else
%restart_on_update arpwatch
%insserv_cleanup
%endif

%files
%defattr(-,root,root)
%if 0%{?has_systemd}
%{_unitdir}/arpwatch@.service
%else
%config /etc/init.d/arpwatch
%{_sbindir}/rcarpwatch
%endif
%{_sbindir}/arpsnmp
%{_sbindir}/arpwatch
%dir /var/lib/arpwatch
%ghost %config(noreplace) /var/lib/arpwatch/arp.dat
%ghost %config(noreplace) /var/lib/arpwatch/arp.dat-
/var/adm/fillup-templates/sysconfig.arpwatch
%doc %{_mandir}/man8/arpsnmp.8.gz
%doc %{_mandir}/man8/arpwatch.8.gz
%doc CHANGES FILES README

%files ethercodes-build
%defattr(-,root,root)
%{_datadir}/arpwatch

%changelog
* Fri Jun 19 2015 lmuelle@suse.com
- Deal with added two whitespaces in more recent oui.txt versions.
  + arpwatch-2.1a15-massagevendor.patch
* Fri Dec  5 2014 lmuelle@suse.com
- Removed executable permission bits from arpwatch@.service file.
* Wed May 14 2014 meissner@suse.com
- added missing %%pre/%%service_add_pre section
* Tue Jan  7 2014 rmilasan@suse.com
- Rework arpwatch.service file to properly support multiple network
  interfaces and arpwatch sysconfig file. (bnc#853384).
* Thu Mar 14 2013 p.drouand@gmail.com
- Drop sysvinit support and add systemd support for opensuse > 11.4
* Wed Jul 18 2012 draht@suse.de
- arpwatch-2.1a11-drop-privs.dif: call initgroups() with pw->pw_gid,
  not NULL, to not have groupid 0 initialized. [bnc#764521]
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Nov 27 2009 mseben@novell.com
- added ARPDIR to build section in spec file, to fix error message
  in logs
* Wed Nov 12 2008 draht@suse.de
- arpwatch-2.1a11-emailaddr.dif for flexibility in sender and
  recipient addresses on commandline.
- arpwatch-2.1a11-drop-privs.dif to run arpwatch as different user
- arpwatch-2.1a11-drop-privs-manpage.dif for the manpage
* Wed Nov 12 2008 draht@suse.de
- start script tuned for multiple interface support and independent
  databases. #149003
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Mon May 14 2007 lrupp@suse.de
- update to 2.1a15
  + let the database files belong to the package
  + build parallel
  + use rpm macros for configure and make
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Apr 18 2005 meissner@suse.de
- Use RPM_OPT_FLAGS.
* Thu Nov 11 2004 lmuelle@suse.de
- Add %%insserv_prereq %%fillup_prereq to prereq.
- Add missing call to %%stop_on_removal (%%preun), %%restart_on_update, and
  %%insserv_cleanup (%%postun).
* Sat Nov  6 2004 lmuelle@suse.de
- Split off massagevendor script and required files as we only need them at
  build time to create the ethercodes.dat file from the IEEE.org meta data.
* Sat Nov  6 2004 lmuelle@suse.de
- Add files needed by massagevendor script, [#48005].
* Fri Jun 25 2004 lmuelle@suse.de
- Update to version 2.1a13.
- Add sysconfig file to allow additional options in the init script.
- Compress source tar ball with bzip2.
- Move IEEE OUI and Company_id file to ethercodes sub package.
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Mon Jan 12 2004 adrian@suse.de
- fix build as user
* Mon Jan 12 2004 adrian@suse.de
- add %%defattr
* Tue Jul 29 2003 aj@suse.de
- Fix for chown changes.
* Thu Jun 12 2003 mmj@suse.de
- Forgot to comment in a line
* Thu Jun 12 2003 mmj@suse.de
- Use BuildRoot
* Wed Feb 26 2003 draht@suse.de
- added /usr/sbin/rcarpwatch symlink (#24163)
* Wed Sep 18 2002 draht@suse.de
- added fileutils to PreReq (#19782)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 22 2002 draht@suse.de
- minor buffer overflow with dns query results, fixed by
  arpwatch-2.1a11-hname-overflow.dif (#18149)
* Mon Jul  8 2002 draht@suse.de
- do not source /etc/rc.config any more.
* Mon Mar 18 2002 draht@suse.de
- minor correction to ethercodes.dat
* Thu Mar 14 2002 draht@suse.de
- added init script (bugzilla #12548)
- fix support for token ring interfaces. Thanks to Bjoern Jacke,
  fixes bugzilla #14504.
- update of vendor table (ethercodes.dat)
* Mon Oct 15 2001 draht@suse.de
- upgrade to version 2.1a11
  syslog(3), but do not send mail for packets from IP 0.0.0.0
* Wed Aug  8 2001 sgf@suse.de
- removed libpcapn from neededforbuild and added libpcap
* Thu Jan 11 2001 draht@suse.de
- New version 2.1a10 fixes tmp file race (security).
* Tue Aug  8 2000 olh@suse.de
- add /usr/share/arpwatch to file list, ethercodes.dat was missing
* Thu Jun  1 2000 kukuk@suse.de
- Use doc macro
* Fri Feb 18 2000 dipa@suse.de
- Changed path for manuals to /usr/share/man and /usr/lib/arpwatch
  to /var/lib/arpwatch for arp.dat and /usr/share/arpwatch for
  ethercodes.dat
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul 22 1999 msrex@suse.de
- Fixed postinstall
* Sun Jul 11 1999 ro@suse.de
- libpcap is an extra package now
* Fri Jun 11 1999 msrex@suse.de
- Spec file created from arpwatch-2.1a4.tar.gz by autospec
* Fri Jun 11 1999 msrex@suse.de
- Spec file created from arpwatch-2.1a4.tar.gz by autospec
